==> ejc-assistrmat-api-3.0.0-20220406.102346-54-sources.jar: com/ejianc/business/assist/rmat/vo/RestituteMaintainVO.java <==
package com.ejianc.business.assist.rmat.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 退赔单维修清单明细
 * 
 * @author generator
 * 
 */
public class RestituteMaintainVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long materialId; // 物料主键
    private String materialName; // 物料名称
    private Long materialTypeId; // 物料类别
    private String materialTypeName; // 物料类别名称
    private String materialCode; // 物料编码
    private String spec; // 规格型号
    private String unitName; // 计量单位
    private BigDecimal sumMaintainMny; // 维修金计算
    private BigDecimal maintainNum; // 报修数量
    private String maintainName; // 维修项名称
    private BigDecimal mny; // 本次维修金额(无税)
    private String maintainUnit; // 维修单位
    private BigDecimal maintainTaxPrice; // 维修项单价
    private BigDecimal taxRate; // 税率
    private BigDecimal tax; // 维修税额
    private String memo; // 备注
    private Long restituteId; // 退赔单主键
    private Long unitId; // 单位主键
    private BigDecimal sumMaintainTaxMny; // 维修金计算(含税)
    private BigDecimal maintainPrice; // 维修项单价(无税)

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getSumMaintainMny() {
        return sumMaintainMny;
    }

    public void setSumMaintainMny(BigDecimal sumMaintainMny) {
        this.sumMaintainMny = sumMaintainMny;
    }
    public BigDecimal getMaintainNum() {
        return maintainNum;
    }

    public void setMaintainNum(BigDecimal maintainNum) {
        this.maintainNum = maintainNum;
    }
    public String getMaintainName() {
        return maintainName;
    }

    public void setMaintainName(String maintainName) {
        this.maintainName = maintainName;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public String getMaintainUnit() {
        return maintainUnit;
    }

    public void setMaintainUnit(String maintainUnit) {
        this.maintainUnit = maintainUnit;
    }
    public BigDecimal getMaintainPrice() {
        return maintainPrice;
    }

    public void setMaintainPrice(BigDecimal maintainPrice) {
        this.maintainPrice = maintainPrice;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }

    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getRestituteId() {
        return restituteId;
    }

    public void setRestituteId(Long restituteId) {
        this.restituteId = restituteId;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public BigDecimal getSumMaintainTaxMny() {
        return sumMaintainTaxMny;
    }

    public void setSumMaintainTaxMny(BigDecimal sumMaintainTaxMny) {
        this.sumMaintainTaxMny = sumMaintainTaxMny;
    }

    public BigDecimal getMaintainTaxPrice() {
        return maintainTaxPrice;
    }

    public void setMaintainTaxPrice(BigDecimal maintainTaxPrice) {
        this.maintainTaxPrice = maintainTaxPrice;
    }
}

==> ejc-assistrmat-api-3.0.0-20220525.100019-115-sources.jar: com/ejianc/business/assist/rmat/vo/RestituteMaintainVO.java <==
package com.ejianc.business.assist.rmat.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 退赔单维修清单明细
 * 
 * @author generator
 * 
 */
public class RestituteMaintainVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long materialId; // 物料主键
    private String materialName; // 物料名称
    private Long materialTypeId; // 物料类别
    private String materialTypeName; // 物料类别名称
    private String materialCode; // 物料编码
    private String spec; // 规格型号
    private String unitName; // 计量单位
    private BigDecimal sumMaintainMny; // 维修金计算
    private BigDecimal maintainNum; // 报修数量
    private String maintainName; // 维修项名称
    private BigDecimal mny; // 本次维修金额(无税)
    private String maintainUnit; // 维修单位
    private BigDecimal maintainTaxPrice; // 维修项单价
    private BigDecimal taxRate; // 税率
    private BigDecimal tax; // 维修税额
    private String memo; // 备注
    private Long restituteId; // 退赔单主键
    private Long unitId; // 单位主键
    private BigDecimal sumMaintainTaxMny; // 维修金计算(含税)
    private BigDecimal maintainPrice; // 维修项单价(无税)

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getSumMaintainMny() {
        return sumMaintainMny;
    }

    public void setSumMaintainMny(BigDecimal sumMaintainMny) {
        this.sumMaintainMny = sumMaintainMny;
    }
    public BigDecimal getMaintainNum() {
        return maintainNum;
    }

    public void setMaintainNum(BigDecimal maintainNum) {
        this.maintainNum = maintainNum;
    }
    public String getMaintainName() {
        return maintainName;
    }

    public void setMaintainName(String maintainName) {
        this.maintainName = maintainName;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public String getMaintainUnit() {
        return maintainUnit;
    }

    public void setMaintainUnit(String maintainUnit) {
        this.maintainUnit = maintainUnit;
    }
    public BigDecimal getMaintainPrice() {
        return maintainPrice;
    }

    public void setMaintainPrice(BigDecimal maintainPrice) {
        this.maintainPrice = maintainPrice;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }

    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getRestituteId() {
        return restituteId;
    }

    public void setRestituteId(Long restituteId) {
        this.restituteId = restituteId;
    }
    @ReferSerialTransfer(referCode = "share-unit")
    public Long getUnitId() {
        return unitId;
    }
    @ReferDeserialTransfer
    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public BigDecimal getSumMaintainTaxMny() {
        return sumMaintainTaxMny;
    }

    public void setSumMaintainTaxMny(BigDecimal sumMaintainTaxMny) {
        this.sumMaintainTaxMny = sumMaintainTaxMny;
    }

    public BigDecimal getMaintainTaxPrice() {
        return maintainTaxPrice;
    }

    public void setMaintainTaxPrice(BigDecimal maintainTaxPrice) {
        this.maintainTaxPrice = maintainTaxPrice;
    }
}
